@@ -10,13 +10,14 @@ with _warnings.catch_warnings():
     import luigi as lg
 
 from . import data
-from .data import Target, ConfigData
+from .data import Target, WrapperTarget
+from .data import ConfigData
 
 from . import cmd
 from .cmd import chdir, mkcd, withEnv, cmdfmt
 
 from . import task
-from .task import Task, STask
+from .task import Task, STask, NITask
 
 from . import envcheck
 from .envcheck import EnvCheck
