@@ -49,7 +49,7 @@ class Target(lg.LocalTarget):
                 pathForMeta = pathForMeta.relative_to(Path.cwd())
             else:
                 pathForMeta = pathForMeta.relative_to(pathForMeta.root)
-        self.pathMeta = str(Path(ConfigData().pathMeta).resolve() / "{}.json".format(pathForMeta))
+        self.pathMeta = str(Path(ConfigData().pathMeta).resolve() / "{}.{}.json".format(pathForMeta, task.getShortStamp()))
         self.pathRel = str(pathForMeta)
 
         self._objMeta = None
@@ -70,26 +70,36 @@ class Target(lg.LocalTarget):
             yield fpw
         self.writeMeta()
 
-    def writeMeta(self):
-        Path(self.pathMeta).parent.mkdir(parents=True, exist_ok=True)
-        objMeta = {'data': {}, 'gen': {
+    def computeSrcMeta(self):
+        return {
             'task': self.task.getSignature(),
             'code': self.task.getCodeHash(),
-            'src': [],
-            }}
-        objMeta['gen']['src'] = self.task.getSrcHash()
+            'src': self.task.getSrcHash(),
+            }
 
+    def computeGenMeta(self):
+        objGen = self.computeSrcMeta()
         if self.task.checkOutputHash:
             pathThis = Path(self.path)
             if pathThis.is_dir():
                 h = md5(usedforsecurity=False)
                 for f in sorted((p for p in pathThis.glob('**/*') if p.is_file())):
-                    h.update(f.read_bytes())
-                objMeta['gen']['out'] = h.hexdigest()
+                    if self.task.simplifiedOutputHash:
+                        h.update(bytes(f.name, 'utf-8'))
+                    else:
+                        h.update(f.read_bytes())
+                objGen['out'] = h.hexdigest()
             else:
-                objMeta['gen']['out'] = md5(pathThis.read_bytes(), usedforsecurity=False).hexdigest()
+                objGen['out'] = md5(pathThis.read_bytes(), usedforsecurity=False).hexdigest()
         else:
-            objMeta['gen']['out'] = '0'
+            objGen['out'] = '0'
+
+        return objGen
+
+    def writeMeta(self):
+        Path(self.pathMeta).parent.mkdir(parents=True, exist_ok=True)
+
+        objMeta = {'data': {}, 'gen': self.computeGenMeta()}
 
         with Path(self.pathMeta).open('w') as fpwMeta:
             json.dump(objMeta, fpwMeta, indent=2, sort_keys=True)
@@ -115,7 +125,7 @@ class Target(lg.LocalTarget):
             return self._objMeta
         return self.writeCache()
 
-    def isOutdated(self):
+    def isOutdated(self, reCompute=False):
         if not Path(self.path).exists():
             return True
         if not Path(self.pathMeta).exists():
@@ -134,4 +144,12 @@ class Target(lg.LocalTarget):
         if self.task.getSrcHash() != objGen['src']:
             return True
 
+        if reCompute:
+            if objGen != self.computeGenMeta():
+                return True
+
         return False
+
+class WrapperTarget(Target):
+    def __init__(self, task, tgt):
+        super().__init__(task, tgt.path)
